# pyconza2014

[![Build Status](https://secure.travis-ci.org/michaeljoseph/pyconza2014.png)](http://travis-ci.org/michaeljoseph/pyconza2014)
[![Stories in Ready](https://badge.waffle.io/michaeljoseph/pyconza2014.png?label=ready)](https://waffle.io/michaeljoseph/pyconza2014) [![pypi version](https://badge.fury.io/py/pyconza2014.png)](http://badge.fury.io/py/pyconza2014)
[![# of downloads](https://pypip.in/d/pyconza2014/badge.png)](https://crate.io/packages/pyconza2014?version=latest)
[![code coverage](https://coveralls.io/repos/michaeljoseph/pyconza2014/badge.png?branch=master)](https://coveralls.io/r/michaeljoseph/pyconza2014?branch=master)

## Overview

PyConZA 2014 Demo

* features
* and stuff 

## Usage

Install `pyconza2014`:

    pip install pyconza2014

Then execute the sample cli:

   pyconza2014

## Documentation

[API Documentation](http://pyconza2014.rtfd.org)

## Testing

Install development requirements:

    pip install -r requirements.txt

Tests can then be run with:

    nosetests

Lint the project with:

    flake8 pyconza2014 tests

## API documentation

Generate the documentation with:

    cd docs && PYTHONPATH=.. make singlehtml

To monitor changes to Python files and execute flake8 and nosetests
automatically, execute the following from the root project directory:

    stir